@@ -184,7 +184,7 @@ class CameraSettings(TelescopeObject):
     eventio_type = 2002
 
     def parse(self):
-        assert_version_in(self, [0, 1, 2, 3, 4, 5])
+        assert_max_version(self, 6)
         self.seek(0)
         byte_stream = BytesIO(self.read())
 
@@ -195,6 +195,12 @@ class CameraSettings(TelescopeObject):
         if self.header.version > 4:
             cam['effective_focal_length'] = read_float(byte_stream)
 
+        if self.header.version > 5:
+            cam['effective_focal_length_x'] = read_float(byte_stream)
+            cam['effective_focal_length_y'] = read_float(byte_stream)
+            cam['effective_focal_length_dx'] = read_float(byte_stream)
+            cam['effective_focal_length_dy'] = read_float(byte_stream)
+
         cam['pixel_x'] = read_array(byte_stream, count=n_pixels, dtype='float32')
         cam['pixel_y'] = read_array(byte_stream, count=n_pixels, dtype='float32')
 
@@ -1759,6 +1765,39 @@ class PixelTriggerTimes(TelescopeObject):
         return trigger_times
 
 
+class PixelMonitoring(TelescopeObject):
+    eventio_type = 2033
+
+    def parse(self):
+        assert_exact_version(self, supported_version=0)
+        byte_stream = BytesIO(self.read())
+
+        flags = read_int(byte_stream)
+        n_pixels = read_int(byte_stream)
+        n_gains = read_short(byte_stream)
+
+        data = {"flags": flags, "n_pixels": n_pixels, "n_gains": n_gains}
+        if flags & 0b0000_0001 != 0:
+            data['nsb_rate'] = read_array(byte_stream, np.float32, n_pixels)
+        if flags & 0b0000_0010 != 0:
+            data['qe_rel'] = read_array(byte_stream, np.float32, n_pixels)
+        if flags & 0b0000_0100 != 0:
+            data['gain_rel'] = read_array(byte_stream, np.float32, n_pixels)
+        if flags & 0b0000_1000 != 0:
+            data['hv_rel'] = read_array(byte_stream, np.float32, n_pixels)
+        if flags & 0b0001_0000 != 0:
+            data['current'] = read_array(byte_stream, np.float32, n_pixels)
+        if flags & 0b0010_0000 != 0:
+            data['fadc_amp_hg'] = read_array(byte_stream, np.float32, n_pixels)
+        if flags & 0b0100_0000 != 0 and n_gains > 1:
+            data['fadc_amp_lg'] = read_array(byte_stream, np.float32, n_pixels)
+        if flags & 0b1000_0000 != 0:
+            data['disabled'] = read_array(byte_stream, np.bool_, n_pixels)
+
+        return data
+
+
+
 def merge_structured_arrays_into_dict(arrays):
     result = dict()
     for array in arrays:
